@@ -43,7 +43,7 @@
 #include "RValue.h"
 #endif
 
-/** The selection part of a a DODS constraint expression may contain one or
+/** The selection part of a a DAP constraint expression may contain one or
     more clauses, separated by ampersands (\&). This is modeled in the DDS
     class structure as a singly-linked list of Clause objects. In addition, a
     constraint expression may be a single function call, also represented in
@@ -64,7 +64,7 @@
     return TRUE if A is a member of L (if the <tt>find()</tt> function is
     defined). 
 
-    <li> A clause that returns a pointer to a DODS BaseType value.
+    <li> A clause that returns a pointer to a DAP BaseType value.
     This is a clause that evaluates to some data value (be it scalar
     or vector).  For example, <tt>sig0()</tt> might be included in the
     constraint expression parser to calculate density from pressure,
@@ -117,74 +117,5 @@ public:
 
   bool value(const string &dataset, DDS &dds, BaseType **value);
 };
-	
-// $Log: Clause.h,v $
-// Revision 1.14  2004/07/07 21:08:47  jimg
-// Merged with release-3-4-8FCS
-//
-// Revision 1.12.2.2  2004/07/02 20:41:51  jimg
-// Removed (commented) the pragma interface/implementation lines. See
-// the ChangeLog for more details. This fixes a build problem on HP/UX.
-//
-// Revision 1.13  2003/12/08 18:02:29  edavis
-// Merge release-3-4 into trunk
-//
-// Revision 1.12.2.1  2003/06/23 11:49:18  rmorris
-// The // #pragma interface directive to GCC makes the dynamic typing functionality
-// go completely haywire under OS X on the PowerPC.  We can't use that directive
-// on that platform and it was ifdef'd out for that case.
-//
-// Revision 1.12  2003/04/22 19:40:27  jimg
-// Merged with 3.3.1.
-//
-// Revision 1.11  2003/02/21 00:14:24  jimg
-// Repaired copyright.
-//
-// Revision 1.10.2.1  2003/02/21 00:10:07  jimg
-// Repaired copyright.
-//
-// Revision 1.10  2003/01/23 00:22:23  jimg
-// Updated the copyright notice; this implementation of the DAP is
-// copyrighted by OPeNDAP, Inc.
-//
-// Revision 1.9  2002/06/18 15:36:24  tom
-// Moved comments and edited to accommodate doxygen documentation-generator.
-//
-// Revision 1.8  2000/09/22 02:17:19  jimg
-// Rearranged source files so that the CVS logs appear at the end rather than
-// the start. Also made the ifdef guard symbols use the same naming scheme and
-// wrapped headers included in other headers in those guard symbols (to cut
-// down on extraneous file processing - See Lakos).
-//
-// Revision 1.7  2000/08/02 22:46:48  jimg
-// Merged 3.1.8
-//
-// Revision 1.6.6.1  2000/08/01 21:09:35  jimg
-// Destructor is now virtual
-//
-// Revision 1.6  1999/04/29 02:29:27  jimg
-// Merge of no-gnu branch
-//
-// Revision 1.5  1998/10/21 16:35:22  jimg
-// Fixed doc++ comments.
-// Changed member names so they start with an underscore - makes the member
-// functions easier to read.
-//
-// Revision 1.4.6.1  1999/02/02 21:56:56  jimg
-// String to string version
-//
-// Revision 1.4  1998/01/12 14:27:56  tom
-// Second pass at class documentation.
-//
-// Revision 1.3  1997/12/18 15:06:10  tom
-// First draft of class documentation, entered in doc++ format,
-// in the comments
-//
-// Revision 1.2  1996/11/27 22:40:18  jimg
-// Added DDS as third parameter to function in the CE evaluator
-//
-// Revision 1.1  1996/05/31 22:45:03  jimg
-// Added.
-//
 
 #endif // _clause_h
