@@ -28,7 +28,7 @@
 
 
 #include <vector>
-#include "Pix.h"
+//#include "Pix.h"
 
 #ifndef _basetype_h
 #include "BaseType.h"
@@ -55,12 +55,6 @@ public:
     virtual ~Constructor();
 
     Constructor &operator=(const Constructor &rhs);
-
-    // Deprecated Pix interface
-    virtual Pix first_var();
-    virtual void next_var(Pix p);
-    virtual BaseType *var(Pix p);
-
     Vars_iter var_begin();
     Vars_iter var_end();
     Vars_riter var_rbegin();
@@ -70,11 +64,6 @@ public:
 
     virtual bool is_linear();
 
-    virtual void print_decl(ostream &os, string space = "    ",
-			    bool print_semi = true,
-			    bool constraint_info = false,
-			    bool constrained = false);
-
     virtual void print_decl(FILE *out, string space = "    ",
 			    bool print_semi = true,
 			    bool constraint_info = false,
