@@ -30,13 +30,13 @@
 //      jhrg,jimg       James Gallagher <jgallagher@gso.uri.edu>
 
 // Implementation of the DODSFilter class. This class is used to build dods
-// filter programs which, along with a CGI program, comprise DODS servers.
+// filter programs which, along with a CGI program, comprise OPeNDAP servers.
 // jhrg 8/26/97
 
 
 #include "config.h"
 
-static char rcsid[] not_used = {"$Id: DODSFilter.cc 12290 2005-10-03 14:14:47Z pwest $"};
+static char rcsid[] not_used = {"$Id: DODSFilter.cc 13423 2006-03-14 22:10:00Z jimg $"};
 
 #include <signal.h>
 
@@ -84,13 +84,19 @@ options: -o <response>: DAS, DDS, DataDDS, DDX, BLOB or Version (Required)\n\
          -r <dir>: Use <dir> as a cache directory\n\
          -l <time>: Conditional request; if data source is unchanged since\n\
                     <time>, return an HTTP 304 response.\n\
+         -t <seconds>: Timeout the handler after <seconds>.\n\
 ";
 
+#if 0
+// Removed the call to waitpid in send_data() because I think calling fflush
+// addresses the problem wait() was supposed to solve and I think calling
+// wait() is the root of ticket #335. jheg 3/10/06
 #ifdef WIN32
 #define WAITPID(pid) while(_cwait(NULL, pid, NULL) > 0)
 #else
 #define WAITPID(pid) while(waitpid(pid, 0, 0) > 0)
 #endif
+#endif
 
 /** Create an instance of DODSFilter using the command line
     arguments passed by the CGI (or other) program.  The default
@@ -255,7 +261,7 @@ DODSFilter::process_options(int argc, char *argv[]) throw(Error)
     DBG(cerr << "Entering process_options... ");
 
     int option_char;
-    GetOpt getopt (argc, argv, "ce:v:d:f:r:l:o:u:");
+    GetOpt getopt (argc, argv, "ce:v:d:f:r:l:o:u:t:");
 
     while ((option_char = getopt()) != EOF) {
 	switch (option_char) {
@@ -702,40 +708,7 @@ DODSFilter::print_usage() throw(Error)
 void 
 DODSFilter::send_version_info()
 {
-    fprintf( stdout, "HTTP/1.0 200 OK\n" ) ;
-    fprintf( stdout, "XDODS-Server: %s\n", d_cgi_ver.c_str() ) ;
-    fprintf( stdout, "Content-Type: text/plain\n" ) ;
-    fprintf( stdout, "\n" ) ;
-
-    fprintf( stdout, "DODS server core software: %s\n", DVR ) ;
-
-    if (d_cgi_ver != "")
-	fprintf( stdout, "Server version: %s\n", d_cgi_ver.c_str() ) ;
-
-    string v = get_dataset_version();
-    if (v != "")
-	fprintf( stdout, "Dataset version: %s\n", v.c_str() ) ;
-    
-    fflush( stdout ) ;
-}
-
-/**
-    @param with_mime_headers If true (the default) send MIME headers. */
-void
-DODSFilter::send_das(ostream &os, DAS &das, const string &anc_location,
-                     bool with_mime_headers)
-{
-    time_t das_lmt = get_das_last_modified_time(anc_location);
-    if (is_conditional()
-	&& das_lmt <= get_request_if_modified_since()
-        && with_mime_headers) {
-	set_mime_not_modified(os);
-    }
-    else {
-        if (with_mime_headers)
-	    set_mime_text(os, dods_das, d_cgi_ver, x_plain, das_lmt);
-	das.print(os);
-    }
+    do_version(d_cgi_ver, get_dataset_version());
 }
 
 /** This function formats and prints an ASCII representation of a
@@ -764,7 +737,7 @@ DODSFilter::send_das(FILE *out, DAS &das, const string &anc_location,
 	    set_mime_text(out, dods_das, d_cgi_ver, x_plain, das_lmt);
 	das.print(out);
     }
-    fflush( stdout ) ;
+    fflush( out ) ;
 }
 
 void
@@ -774,31 +747,6 @@ DODSFilter::send_das(DAS &das, const string &anc_location,
     send_das(stdout, das, anc_location, with_mime_headers);
 }
 
-void
-DODSFilter::send_dds(ostream &os, DDS &dds, bool constrained,
-		     const string &anc_location,
-                     bool with_mime_headers)
-{
-    // If constrained, parse the constriant. Throws Error or InternalErr.
-    if (constrained)
-	dds.parse_constraint(d_ce, os, true);
-
-    time_t dds_lmt = get_dds_last_modified_time(anc_location);
-    if (is_conditional() 
-	&& dds_lmt <= get_request_if_modified_since()
-        && with_mime_headers) {
-	set_mime_not_modified(os);
-    }
-    else {
-        if (with_mime_headers)
-	    set_mime_text(os, dods_dds, d_cgi_ver, x_plain, dds_lmt);
-	if (constrained)
-	    dds.print_constrained(os);
-	else
-	    dds.print(os);
-    }
-}
-
 /** This function formats and prints an ASCII representation of a
     DDS on stdout.  When called by a CGI program, this has the
     effect of sending a DDS object back to the client
@@ -821,7 +769,7 @@ DODSFilter::send_dds(FILE *out, DDS &dds, bool constrained,
 {
     // If constrained, parse the constriant. Throws Error or InternalErr.
     if (constrained)
-	dds.parse_constraint(d_ce, out, true);
+	dds.parse_constraint(d_ce);
 
     time_t dds_lmt = get_dds_last_modified_time(anc_location);
     if (is_conditional() 
@@ -838,7 +786,7 @@ DODSFilter::send_dds(FILE *out, DDS &dds, bool constrained,
 	    dds.print(out);
     }
 
-    fflush( stdout ) ;
+    fflush( out ) ;
 }
 
 void
@@ -915,6 +863,8 @@ DODSFilter::dataset_constraint(DDS &dds, FILE *out, time_t /* lmt */)
     @param anc_location A directory to search for ancillary files (in
     addition to the CWD).  This is used in a call to 
     get_data_last_modified_time(). 
+    @param with_mime_headers If true, include the MIME headers in the response.
+    Defaults to true.
     @return void */
 void
 DODSFilter::send_data(DDS &dds, FILE *data_stream, const string &anc_location,
@@ -960,10 +910,16 @@ DODSFilter::send_data(DDS &dds, FILE *data_stream, const string &anc_location,
     else
 	dataset_constraint(dds, data_stream, data_lmt);
     
-    //fclose(data_stream);
     fflush(data_stream);
-    if (compress)
+#if 0
+    // This call seems to be why requests for data in the browser hang for so
+    // long. I think it might have been added to fix a problem that was then
+    // really fixed by calling fflush() (which was added by Patrick West). 
+    // jhrg 3/10/06
+    if (compress) {
 	WAITPID(childpid);
+    }
+#endif
 }
 
 /** Send the DDX response. The DDX never contains data, instead it holds a
@@ -972,13 +928,15 @@ DODSFilter::send_data(DDS &dds, FILE *data_stream, const string &anc_location,
     servers. 
 
     @param out Destination
-    @param dds The dataset's DDS \e with attributes in the variables. */
+    @param dds The dataset's DDS \e with attributes in the variables.
+    @param with_mime_headers If true, include the MIME headers in the response.
+    Defaults to true. */
 void
 DODSFilter::send_ddx(DDS &dds, FILE *out, bool with_mime_headers)
 {
     // If constrained, parse the constriant. Throws Error or InternalErr.
     if (!d_ce.empty())
-	dds.parse_constraint(d_ce, out, true);
+	dds.parse_constraint(d_ce);
 
     time_t data_lmt = get_data_last_modified_time(d_anc_dir);
 
@@ -1015,7 +973,7 @@ DODSFilter::send_blob(DDS &dds, FILE *out, bool with_mime_headers)
 	return;
     }
 
-    dds.parse_constraint(d_ce, out, true);
+    dds.parse_constraint(d_ce);
   
     // Handle *functional* constraint expressions specially 
     if (dds.functional_expression()) {
@@ -1056,383 +1014,3 @@ DODSFilter::send_blob(DDS &dds, FILE *out, bool with_mime_headers)
     }
 }
 
-// $Log: DODSFilter.cc,v $
-// Revision 1.50  2005/04/07 22:32:47  jimg
-// Updated doxygen comments: fixed errors; updated comments about set_read_p.
-// Removed the VirtualCtor classes. Added a README about the factory
-// classes.
-//
-// Revision 1.49  2005/01/28 17:25:12  jimg
-// Resolved conflicts from merge with release-3-4-9
-//
-// Revision 1.37.2.13  2004/12/24 17:57:15  dan
-// Added call to dds.tag_nested_sequences() in send_data() method.
-// This is required to tag Sequences so that new Sequence::serialize()
-// logic will work properly.
-//
-// Revision 1.37.2.12  2004/10/22 20:13:30  jimg
-// Another fix from John Alison: The original code did not always use
-// d_anc_dir(from -d cmd line arg) tho it did always use d_anc_file.
-//
-// Revision 1.37.2.11  2004/10/15 15:08:34  jimg
-// Fixed a bug in get_data_last_modified_time() reported by John Alison:
-// The second call to find_ancillary_file() used "dds" when it should have used
-// "das".
-//
-// Revision 1.48  2004/07/07 21:08:47  jimg
-// Merged with release-3-4-8FCS
-//
-// Revision 1.37.2.10  2004/07/02 20:41:51  jimg
-// Removed (commented) the pragma interface/implementation lines. See
-// the ChangeLog for more details. This fixes a build problem on HP/UX.
-//
-// Revision 1.47  2004/06/28 17:01:22  pwest
-// saving string representation of response type
-//
-// Revision 1.37.2.9  2004/04/19 01:42:29  rmorris
-// Output filter response in binary mode under win32 to omit
-// mapping NL to  CR->NL on that platform.  win32 and unix need
-// to serve in an identical manner.
-//
-// Revision 1.46  2004/02/19 19:42:52  jimg
-// Merged with release-3-4-2FCS and resolved conflicts.
-//
-// Revision 1.37.2.7  2004/02/10 21:05:53  jimg
-// I broke the AlarmHandler class out into its own header. Included here.
-//
-// Revision 1.45  2004/01/26 18:58:01  jimg
-// Build fixes.
-//
-// Revision 1.44  2004/01/23 17:12:29  jimg
-// Removed errant DBG() with d_ver field (that field is no longer part of the
-// class).
-//
-// Revision 1.43  2003/12/10 21:11:57  jimg
-// Merge with 3.4. Some of the files contains erros (some tests fail). See
-// the ChangeLog for information about fixes.
-//
-// Revision 1.42  2003/12/08 18:02:29  edavis
-// Merge release-3-4 into trunk
-//
-// Revision 1.41  2003/09/25 22:37:34  jimg
-// Misc changes.
-//
-// Revision 1.37.2.6  2003/09/06 22:29:00  jimg
-// Updated the documentation. Added instrumentation to DODSFilter::send().
-//
-// Revision 1.37.2.5  2003/08/17 01:37:54  rmorris
-// Removed "smart timeout" functionality under win32.  alarm() and
-// SIGALRM are not supported under win32 - plus that functionality
-// appears to be server-side only and win32 is client-side only.
-//
-// Revision 1.37.2.4  2003/07/25 06:04:28  jimg
-// Refactored the code so that DDS:send() is now incorporated into
-// DODSFilter::send_data(). The old DDS::send() is still there but is
-// depracated.
-// Added 'smart timeouts' to all the variable classes. This means that
-// the new server timeouts are active only for the data read and CE
-// evaluation. This went inthe BaseType::serialize() methods because it
-// needed to time both the read() calls and the dds::eval() calls.
-//
-// Revision 1.37.2.3  2003/07/23 23:56:36  jimg
-// Now supports a simple timeout system.
-//
-// Revision 1.37.2.2  2003/06/14 00:57:39  rmorris
-// Patched in a change lost during move to the 3-4 branch.
-//
-// Revision 1.37.2.1  2003/06/05 20:15:25  jimg
-// Removed many uses of strstream and replaced them with stringstream.
-//
-// Revision 1.40  2003/05/27 21:39:54  jimg
-// Added DDX_Response to the set_response() method.
-//
-// Revision 1.39  2003/05/23 03:24:57  jimg
-// Changes that add support for the DDX response. I've based this on Nathan
-// Potter's work in the Java DAP software. At this point the code can
-// produce a DDX from a DDS and it can merge attributes from a DAS into a
-// DDS to produce a DDX fully loaded with attributes. Attribute aliases
-// are not supported yet. I've also removed all traces of strstream in
-// favor of stringstream. This code should no longer generate warnings
-// about the use of deprecated headers.
-//
-// Revision 1.38  2003/05/13 22:10:58  jimg
-// MOdified DODSFilter so that it takes a -o switch which names the type
-// of response to generate. This can be used to build a single hander
-// which can return all of the responses.
-//
-// Revision 1.37  2003/04/22 19:40:27  jimg
-// Merged with 3.3.1.
-//
-// Revision 1.30.2.4  2003/04/06 23:04:34  rmorris
-// Make the using:: statements for min, max #ifdef'd out for win32.
-//
-// Revision 1.36  2003/03/13 23:58:25  jimg
-// Hacked documentation. Added process_options() and initialize(). Changed the
-// names of the fields so that they all begin with 'd_'.
-//
-// Revision 1.30.2.3  2003/03/03 19:31:58  jimg
-// Added using std::min and std::max back to the code. They are needed for gcc
-// 3.2.1. and should be present for any ANSI C++ compiler; gcc 2 is laid back
-// about that stuff.
-//
-// Revision 1.35  2003/02/21 00:14:24  jimg
-// Repaired copyright.
-//
-// Revision 1.30.2.2  2003/02/21 00:10:07  jimg
-// Repaired copyright.
-//
-// Revision 1.30.2.1  2003/02/17 23:38:21  rmorris
-// Fix to compile under win32.  Problems with min/max def's under win32 and
-// UNIX.
-//
-// Revision 1.34  2003/02/09 12:18:31  rmorris
-// Fix to compile under win32.  Problem with min/max diffs under win32 and unix.
-//
-// Revision 1.30  2003/01/23 00:22:24  jimg
-// Updated the copyright notice; this implementation of the DAP is
-// copyrighted by OPeNDAP, Inc.
-//
-// Revision 1.29  2003/01/13 22:55:07  jimg
-// When a filter program got the -V option without a dataset, It was returning
-// usage information. Fixed.
-//
-// Revision 1.28  2003/01/10 19:46:40  jimg
-// Merged with code tagged release-3-2-10 on the release-3-2 branch. In many
-// cases files were added on that branch (so they appear on the trunk for
-// the first time).
-//
-// Revision 1.23.2.19  2002/12/20 00:46:58  jimg
-// I removed the include of sys/ddi.h. This header was not found on my
-// machine (Red Hat 7.3).
-//
-// Revision 1.23.2.18  2002/12/17 22:35:02  pwest
-// Added and updated methods using stdio. Deprecated methods using iostream.
-//
-// Revision 1.23.2.17  2002/12/01 14:37:52  rmorris
-// Smalling changes for the win32 porting and maintenance work.
-//
-// Revision 1.23.2.16  2002/11/21 21:24:17  pwest
-// memory leak cleanup and file descriptor cleanup
-//
-// Revision 1.23.2.15  2002/08/08 06:54:57  jimg
-// Changes for thread-safety. In many cases I found ugly places at the
-// tops of files while looking for globals, et c., and I fixed them up
-// (hopefully making them easier to read, ...). Only the files RCReader.cc
-// and usage.cc actually use pthreads synchronization functions. In other
-// cases I removed static objects where they were used for supposed
-// improvements in efficiency which had never actually been verifiied (and
-// which looked dubious).
-//
-// Revision 1.23.2.14  2002/06/18 22:50:06  jimg
-// Added include of util.h. This was necessary because I removed the include of
-// Connect.h from cgi_util.h.
-//
-// Revision 1.27  2002/06/18 15:36:24  tom
-// Moved comments and edited to accommodate doxygen documentation-generator.
-//
-// Revision 1.26  2002/06/03 22:21:15  jimg
-// Merged with release-3-2-9
-//
-// Revision 1.23.2.13  2002/03/29 18:40:20  jimg
-// Updated comments and/or removed dead code.
-//
-// Revision 1.23.2.12  2002/01/28 20:34:25  jimg
-// *** empty log message ***
-//
-// Revision 1.25  2001/08/24 17:46:22  jimg
-// Resolved conflicts from the merge of release 3.2.6
-//
-// Revision 1.23.2.11  2001/08/21 14:54:29  dan
-// Added a set_dataset_name method to provide a mechanism to change the
-// dataset name in the DODSFilter class, which currently can only be set
-// by running the constructor.   This method was required for a modification
-// to the jg-dods server which now support relative pathnames as part of
-// the object name.
-//
-// Revision 1.23.2.10  2001/08/18 00:18:41  jimg
-// Removed WIN32 compile guards from using statements.
-//
-// Revision 1.23.2.9  2001/07/28 01:04:46  jimg
-// Rewrote calls to www2id since it now uses strings and not Regexs.
-// Removed old code.
-//
-// Revision 1.24  2001/06/15 23:49:02  jimg
-// Merged with release-3-2-4.
-//
-// Revision 1.23.2.8  2001/06/14 21:31:15  jimg
-// Modified the handling of version requests as signaled by this class'
-// client. The version number printed from this class is for the core software.
-// The cgi_version property should be set by the client so that the
-// send_version() method will write both the core and server (CGI) version
-// numbers.
-//
-// Revision 1.23.2.7  2001/06/08 21:57:49  jimg
-// Really fixed the usage message this time...
-//
-// Revision 1.23.2.6  2001/06/08 21:37:02  jimg
-// Corrected the usage message. Added to text in the Error thrown as well.
-//
-// Revision 1.23.2.5  2001/05/16 21:12:26  jimg
-// Modified the ctor and set_ce() so that www2id() does not replace %20s
-// in either the dataset name or the CE. This keeps the parsers from gaging
-// on spaces (which they think are word separators).
-//
-// Revision 1.23.2.4  2001/05/07 17:19:08  jimg
-// The dataset name and CE are now passed through www2id() which removes WWW
-// escape sequences (those %<hex digit><hex digit> things) and replaces them
-// with the correct ASCII characters. Fixed a bug where DAS::parse(FILE *)
-// and DDS::parse(FILE *) were often called with a null FILE *.
-//
-// Revision 1.23.2.3  2001/05/03 23:36:31  jimg
-// Removed all the catch clauses for Error and InternalErr. Code that uses
-// DODSFilter should catch (and probably serialize) Error and its children. All
-// of the current URI servers do this.
-//
-// Revision 1.23.2.2  2001/05/03 20:23:47  jimg
-// Added the methods is_conditional() and get_request_if_modified_since().
-// These are used to determine if the request was conditional and, if so, to
-// get the value of the If-Modified-Since header. Modified the send_das(),
-// send_dds() and send_data() methods so that a 304 (not modified) response
-// is sent if appropriate.
-//
-// Revision 1.23.2.1  2001/04/23 22:34:46  jimg
-// Added support for the Last-Modified MIME header in server responses.`
-//
-// Revision 1.23  2000/10/30 17:21:27  jimg
-// Added support for proxy servers (from cjm).
-//
-// Revision 1.22  2000/09/22 02:17:19  jimg
-// Rearranged source files so that the CVS logs appear at the end rather than
-// the start. Also made the ifdef guard symbols use the same naming scheme and
-// wrapped headers included in other headers in those guard symbols (to cut
-// down on extraneous file processing - See Lakos).
-//
-// Revision 1.21  2000/09/21 16:22:07  jimg
-// Merged changes from Jose Garcia that add exceptions to the software.
-// Many methods that returned error codes now throw exectptions. There are
-// two classes which are thrown by the software, Error and InternalErr.
-// InternalErr is used to report errors within the library or errors using
-// the library. Error is used to reprot all other errors. Since InternalErr
-// is a subclass of Error, programs need only to catch Error.
-//
-// Revision 1.20  2000/07/09 22:05:35  rmorris
-// Changes to increase portability, minimize ifdef's for win32 and account
-// for differences in the iostreams implementations.
-//
-// Revision 1.19  2000/06/07 19:33:21  jimg
-// Merged with verson 3.1.6
-//
-// Revision 1.18  2000/06/07 18:06:58  jimg
-// Merged the pc port branch
-//
-// Revision 1.17.10.1  2000/06/02 18:16:48  rmorris
-// Mod's for port to Win32.
-//
-// Revision 1.16.2.3  2000/05/18 20:45:27  jimg
-// added set_ce(). Maybe add more set methods?
-//
-// Revision 1.17.4.3  2000/03/08 00:09:04  jgarcia
-// replace ostrstream with string;added functions to convert from double and
-// long to string
-//
-// Revision 1.17.4.2  2000/02/17 05:03:12  jimg
-// Added file and line number information to calls to InternalErr.
-// Resolved compile-time problems with read due to a change in its
-// parameter list given that errors are now reported using exceptions.
-//
-// Revision 1.17.4.1  2000/02/07 21:11:36  jgarcia
-// modified prototypes and implementations to use exceeption handling
-//
-// Revision 1.16.2.2  1999/09/08 22:36:51  jimg
-// Fixed the spelling of version (was vision) and the usage line (did not
-// include -V).
-//
-// Revision 1.17  1999/09/03 22:07:44  jimg
-// Merged changes from release-3-1-1
-//
-// Revision 1.16.2.1  1999/08/28 06:43:04  jimg
-// Fixed the implementation/interface pragmas and misc comments
-//
-// Revision 1.16  1999/07/22 17:11:51  jimg
-// Merged changes from the release-3-0-2 branch
-//
-// Revision 1.15.4.1  1999/06/01 15:43:51  jimg
-// Made dods/3.0 the default version number. This makes is simpler to debug
-// dods servers since running the server filter programs will generate valid
-// headers now. Before you had to remember to use the -v option and give a
-// version string/number or the MIME header would not be valid. This confused
-// the MIME header parse which hosed the data stream.
-//
-// Revision 1.15  1999/05/26 17:37:02  jimg
-// Added a bit where, before sending caught Error objects to the client, we
-// write the message to t eh httpd's error_log.
-//
-// Revision 1.14  1999/05/25 21:57:52  dan
-// Added an optional second argument to read_ancillary_dds to support
-// JGOFS usage.
-//
-// Revision 1.13  1999/05/25 21:54:19  dan
-// Added an optional argument to read_ancillary_das to support JGOFS
-// data object usage, where the location of the ancillary DAS file isn't
-// readily available through the 'dataset' argument of the command line.
-//
-// Revision 1.12  1999/05/21 17:15:46  jimg
-// Added instrumentation to the ctor. This simplifies debugging the interaction
-// between the filter programs and the perl script.
-//
-// Revision 1.11  1999/05/19 23:56:57  jimg
-// Changed the support address from @dods to @unidata
-//
-// Revision 1.10  1999/05/05 00:36:36  jimg
-// Added the -V option. -v now is used to pass the version information from
-// the CGI to the C++ software; -V triggers output of the version message.
-// This allows the DODSFilter class to pass information about the server's
-// version to the core software. All set_mime_*() functions are now passes
-// the CGI version information so that all MIME headers contain information
-// about the server's version. Added the get_cgi_version() member function so
-// that clients of DODSFilter can find out the version number.
-//
-// Revision 1.9  1999/05/04 19:47:21  jimg
-// Fixed copyright statements. Removed more of the GNU classes.
-//
-// Revision 1.8  1999/04/29 02:29:28  jimg
-// Merge of no-gnu branch
-//
-// Revision 1.7  1999/02/22 22:59:07  jimg
-// Added the get_accept_types() accessor.
-// Changed the ctor so that the -t option is recognized.
-//
-// Revision 1.6  1998/12/16 19:10:53  jimg
-// Added support for XDODS-Server MIME header. This fixes a problem where our
-// use of Server clashed with Java.
-//
-// Revision 1.5  1998/11/10 01:04:42  jimg
-// Added `ends' to strings made with ostrstream (fixes a bug found with
-// purify).
-// Added catch for throws from within the CE evaluation functions.
-//
-// Revision 1.4.2.2  1999/02/05 09:32:34  jimg
-// Fixed __unused__ so that it not longer clashes with Red Hat 5.2 inlined
-// math code. 
-//
-// Revision 1.4.2.1  1999/02/02 21:56:57  jimg
-// String to string version
-//
-// Revision 1.4  1998/08/06 16:12:30  jimg
-// Added cache dir methods and stuff to ctor (from jeh)
-//
-// Revision 1.3  1998/03/19 23:34:21  jimg
-// Fixed calls to set_mime_*().
-// Removed the compression code (it is now in DDS::send().
-// Removed old code (that was surrounded by #if 0 ... #endif).
-//
-// Revision 1.2  1998/02/11 22:00:46  jimg
-// Added call to util.cc:deflate_exists() to send_data(). This means that
-// send_data() will only try to start the compressor if an executable copy of
-// deflate can be found. If, for any reason a copy of deflate cannot be found
-// data is sent without trying to compress it.
-//
-// Revision 1.1  1997/08/28 20:39:02  jimg
-// Created
-//
-
