@@ -11,9 +11,7 @@ typedef union {
 #define	SCAN_STR	258
 #define	SCAN_ERROR	259
 #define	SCAN_CODE	260
-#define	SCAN_PTYPE	261
-#define	SCAN_MSG	262
-#define	SCAN_PROGRAM	263
+#define	SCAN_MSG	261
 
 
 extern YYSTYPE Errorlval;
