@@ -27,7 +27,7 @@
 #include "config.h"
 
 static char rcsid[] not_used =
-    { "$Id: HTTPConnect.cc 11932 2005-08-11 22:26:27Z jimg $" };
+    { "$Id: HTTPConnect.cc 13266 2006-02-23 23:33:47Z jimg $" };
 
 #include <stdio.h>
 
@@ -123,9 +123,10 @@ Please report this to support@unidata.ucar.edu.");
 class ParseHeader : public unary_function<const string &, void> {
     ObjectType type;		// What type of object is in the stream?
     string server;		// Server's version string.
+    string protocol;            // Server's protocol version.
 
 public:
-    ParseHeader() :type(unknown_type), server("dods/0.0") { }
+    ParseHeader() :type(unknown_type), server("dods/0.0"), protocol("2.0") { }
 
     void operator()(const string &header) {
 	std::istringstream line(header);
@@ -140,13 +141,30 @@ public:
 	    DBG2(cout << name << ": " << value << endl);
 	    type = get_type(value);
 	}
-	else if (name == "xdods-server:") {
+        // The second test (== "dods/0.0") tests if xopendap-server has already
+        // been seen. If so, use that header in preference to the old
+        // XDODS-Server header. jhrg 2/7/06
+	else if (name == "xdods-server:" && server == "dods/0.0") {
 	    string value; 
 	    line >> value;
 	    downcase(value);
 	    DBG2(cout << name << ": " << value << endl);
 	    server = value;
 	}
+        else if (name == "xopendap-server:") {
+            string value; 
+            line >> value;
+            downcase(value);
+            DBG2(cout << name << ": " << value << endl);
+            server = value;
+        }
+        else if (name == "xdap:") {
+            string value; 
+            line >> value;
+            downcase(value);
+            DBG2(cout << name << ": " << value << endl);
+            protocol = value;
+        }
 	else if (server == "dods/0.0" && name == "server:") {
 	    string value; 
 	    line >> value;
@@ -168,6 +186,10 @@ public:
     string get_server() {
 	return server;
     }
+
+    string get_protocol() {
+        return protocol;
+    }
 };
 
 /** A libcurl callback function used to read response headers. Read headers,
@@ -507,6 +529,7 @@ HTTPConnect::fetch_url(const string &url) throw(Error, InternalErr)
 
     stream->set_type(parser.get_object_type());
     stream->set_version(parser.get_server());
+    stream->set_protocol(parser.get_protocol());
     
     return stream;
 }
@@ -643,16 +666,6 @@ HTTPConnect::caching_fetch_url(const string &url) throw(Error, InternalErr)
 		    FILE *s = d_http_cache->get_cached_response(url, *headers);
 		    HTTPCacheResponse *crs 
 			= new HTTPCacheResponse(s, headers, d_http_cache);
-#if 0
-		    // Problem: When a 304 comes back it sometimes (?) has
-		    // only a Date header. We need all the headers, so after
-		    // updating the cache with the single Date header, get
-		    // _all_ the headers and return them. See bug 672.
-		    // 10/10/03 jhrg
-		    FILE *s = d_http_cache->get_cached_response_body(url);
-		    HTTPCacheResponse *crs 
-			= new HTTPCacheResponse(s, resp_hdrs, d_http_cache);
-#endif
 		    return crs;
 		}
 		break;
@@ -788,256 +801,3 @@ HTTPConnect::set_credentials(const string &u, const string &p)
 
     d_upstring = u + ":" + p;
 }
-
-// $Log: HTTPConnect.cc,v $
-// Revision 1.22  2005/04/21 17:51:34  jimg
-// Checkpoint: Build works
-//
-// Revision 1.21  2005/04/21 17:48:59  jimg
-// Removed PTHREADS compile-time switch. Also, checkpoint for the build
-// work.
-//
-// Revision 1.20  2005/04/15 21:17:23  jimg
-// Remove include of config.h from HTTPCache.h.
-//
-// Revision 1.19  2005/01/28 17:25:12  jimg
-// Resolved conflicts from merge with release-3-4-9
-//
-// Revision 1.14.2.17  2004/08/24 20:03:15  jimg
-// Changed the way HTTPResponse deletes the temporary files created to hold
-// HTTP responses. Before this was done without using HTTPConnect's
-// close_temp() function. Instead, ~HTTPResponse() called unlink() on the
-// filename and then ~Response() called fclose on the FILE *. I think this
-// breaks on win32. THe simplest solution was to make ~HTTPResponse() use
-// the close_temp() function. I also had to edit the ~Response() method to
-// check that d_stream was not null before calling fclose() there.
-//
-// Revision 1.18  2004/07/07 21:08:47  jimg
-// Merged with release-3-4-8FCS
-//
-// Revision 1.14.2.16  2004/07/02 20:41:52  jimg
-// Removed (commented) the pragma interface/implementation lines. See
-// the ChangeLog for more details. This fixes a build problem on HP/UX.
-//
-// Revision 1.14.2.15  2004/06/21 20:45:16  jimg
-// Changes for proxy use: Proxy passwords are now supported. The proxy_for
-// feature has been disabled.
-//
-// Revision 1.17  2004/04/12 16:21:56  jimg
-// Removed obsolete CURLOPT_MUTE.
-//
-// Revision 1.14.2.14  2004/04/08 23:46:12  jimg
-// Fixes for the build on the Alpha/Tru64 platform. I removed the call to
-// curl's MUTE option since it's deprecated by the latest rev of that
-// library. I added regex-0.12 to the code and modified configure.in,
-// Makefile.in and GNU/Regex.cc to use it in place of librx (which won't
-// build on this plaform). Doing this gets rid of a library dependency, too.
-//
-// Revision 1.16  2004/02/19 19:42:52  jimg
-// Merged with release-3-4-2FCS and resolved conflicts.
-//
-// Revision 1.14.2.13  2004/02/11 21:52:23  jimg
-// Added two char* arrays which hold HTTP 1.1 error messages. These are used to
-// provide better feedback when the OPeNDAP server's httpd returns an error
-// (i.e., when the request does not even make it into the Dispatch code). I also
-// tidied up some calls to delete by setting 'x' in delete x to null after the
-// call to delete.
-//
-// Revision 1.14.2.12  2004/02/04 00:05:11  jimg
-// Memory errors: I've fixed a number of memory errors (leaks, references)
-// found using valgrind. Many remain. I need to come up with a systematic
-// way of running the tests under valgrind.
-//
-// Revision 1.15  2003/12/08 18:02:29  edavis
-// Merge release-3-4 into trunk
-//
-// Revision 1.14.2.11  2003/10/10 23:13:12  jimg
-// Fix for bug 672: When a cached response needs to be validated and the origin
-// server returns a 304 response (i.e., use what you've got) only the Date
-// header is sent with the 304 response. This code was using the
-// HTTPCache::get_cahced_body() method and the header from the 304 response.
-// This meant that Content-Description and server/DAP-protocol version headers
-// were missing in the Response object returned by caching_fetch_url(). This
-// caused an Error to be thrown in Connect (because we just modified it to
-// require the Content-Description information). I fixed this by using the
-// get_cached_response() method which reads the body _and_ headers from the
-// cache.
-//
-// Revision 1.14.2.10  2003/10/03 16:21:17  jimg
-// Minor changes: save_raw_http_headers is now static and some comments were
-// fixed.
-//
-// Revision 1.14.2.9  2003/09/08 18:54:41  jimg
-// Now we check to see that USE_CACHE is set (1) in .dodsrc before trying to
-// create an instance of HTTPCache. This makes sense since HTTPCache will create
-// teh cache directory structure regardless of the value of USE_CACHE. If
-// USE_CACHE is clear (0), the the pointer to the HTTPCache instance is zero.
-//
-// Revision 1.14.2.8  2003/09/06 22:37:50  jimg
-// Updated the documentation.
-//
-// Revision 1.14.2.7  2003/08/18 00:33:14  rmorris
-// Win32-related cleanup.
-//
-// Revision 1.14.2.6  2003/07/29 01:46:33  jimg
-// Now supports digest authentication.
-//
-// Revision 1.14.2.5  2003/07/26 02:08:18  jimg
-// Added curl options to suppress signals and supply passwords to proxy servers.
-//
-// Revision 1.14.2.4  2003/07/16 04:20:55  jimg
-// Fixed some documentation.
-//
-// Revision 1.14.2.3  2003/05/06 06:44:15  jimg
-// Modified HTTPConnect so that the response headers are no longer a class
-// member. This cleans up the class interface and paves the way for using
-// the multi interface of libcurl. That'll have to wait for another day...
-//
-// Revision 1.14.2.2  2003/05/05 21:45:30  jimg
-// Added support for the http://user:passwd@machine... convention.
-//
-// Revision 1.14.2.1  2003/05/05 19:45:25  jimg
-// Fixed a problem where libcurl sent a Pragma: no-cache request header. This
-// caused third-party caches to not cache requests. I fixed this by forcing
-// libcurl to send an empty Pragma: header (suggested by Benno Blumenthal and
-// the libcurl list). At the same time I repaired the set_accept_deflate method
-// so that it worked (it didn't but nobody noticed...) and changed the class so
-// that *any* headers present in the new filed d_request_headers are sent
-// whenever read_url() is run. I also now set the User-Agent request header to
-// a value that announces who we are.
-//
-// Revision 1.14  2003/05/02 16:22:52  jimg
-// Minor fixes: Fixed a spelling mistake and removed #if 1 ... #endif. Mostly I
-// wanted this code in for the 3.4 branch.
-//
-// Revision 1.13  2003/05/01 23:37:01  jimg
-// Changed some of struct Functors to classes.
-//
-// Revision 1.12  2003/05/01 23:25:14  jimg
-// Fixed a bug in the code that handles conditional requests. Once a conditional
-// request was made, the curl_slist was freed but the HTTPHEADER option (set
-// with curl_easy_setopt()) was not cleared. Subsequent calls to
-// curl_easy_perform() would try to use the freed slist with predictably bad
-// results. Also removed strstream code in place of Rob's stringstream
-// replacement for Win32.
-//
-// Revision 1.11  2003/04/22 19:40:27  jimg
-// Merged with 3.3.1.
-//
-// Revision 1.3.2.4  2003/04/18 03:22:58  jimg
-// Undid a typo that made it into CVS...
-//
-// Revision 1.3.2.3  2003/04/18 03:21:17  jimg
-// I removed some old code (some of which has been seriously hacked already on
-// the trunk) and changed the catch part of a try-catch block so that it only
-// catches and re-throws the objects listed in the throw() declaration. Using
-// catch(...) and re-throwing when exceptions have been explicitly declared
-// aborts.
-//
-// Revision 1.3.2.2  2003/04/09 20:36:21  jimg
-// Changed the catch(...) clauses to ones that explicitly name the objects. By
-// just using catch(...) with a method that declares the types of exceptions it
-// throws causes an abort if the catch(...) re-throws the exception.
-// I also removed some old code that called output(), et cetera.
-//
-// Revision 1.10  2003/03/13 23:51:31  jimg
-// Added a DBG2 statement to track down a bug. Useful when you cannot use a
-// debugger.
-//
-// Revision 1.9  2003/03/04 21:41:44  jimg
-// Removed code in #if 0 ... #endif. This was mostly WIN32 code that I don't
-// think we need anymore.
-//
-// Revision 1.8  2003/03/04 17:28:37  jimg
-// Switched to Response objects. Removed unneeded methods. The Response objects
-// now control the release of resources such as deleting temporary files, et c.
-//
-// Revision 1.7  2003/02/27 23:36:10  jimg
-// Added set_accept_deflate() method.
-//
-// Revision 1.6  2003/02/27 08:32:51  jimg
-// Removed old code.
-//
-// Revision 1.5  2003/02/21 00:14:24  jimg
-// Repaired copyright.
-//
-// Revision 1.3.2.1  2003/02/21 00:10:07  jimg
-// Repaired copyright.
-//
-// Revision 1.4  2003/02/20 23:13:52  jimg
-// Fixed the comment for getch_url.
-//
-// Revision 1.3  2003/01/23 00:22:24  jimg
-// Updated the copyright notice; this implementation of the DAP is
-// copyrighted by OPeNDAP, Inc.
-//
-// Revision 1.2  2003/01/10 19:46:40  jimg
-// Merged with code tagged release-3-2-10 on the release-3-2 branch. In many
-// cases files were added on that branch (so they appear on the trunk for
-// the first time).
-//
-// Revision 1.1.2.14  2002/12/27 00:56:24  jimg
-// is_response_present() is now deprecated.
-//
-// Revision 1.1.2.13  2002/12/24 00:22:00  jimg
-// Removed the output() and close_output() methods from the interface.
-// The fetch_url() method now returns a FILE * instead of forcing clients to
-// call the output() method.
-//
-// Revision 1.1.2.12  2002/12/05 20:36:19  pwest
-// Corrected problems with IteratorAdapter code, making methods non-inline,
-// creating source files and template instantiation file. Cleaned up file
-// descriptors and memory management problems. Corrected problem in Connect
-// where the xdr source was not being cleaned up or a new one created when a
-// new file was opened for reading.
-//
-// Revision 1.1.2.11  2002/11/21 21:24:17  pwest
-// memory leak cleanup and file descriptor cleanup
-//
-// Revision 1.1.2.10  2002/10/18 22:48:46  jimg
-// Resolved conflicts with Rob's changes
-//
-// Revision 1.1.2.9  2002/09/22 14:31:56  rmorris
-// Minor mod's to get the code to go through VC++.
-//
-// Revision 1.1.2.8  2002/09/14 03:40:32  jimg
-// Added get_response_headers() method. This method provides a way to access the
-// headers included in a response, specifically so that they can be cached.
-// Added is_response_present() which returns true when fetch_url() has been
-// called and a response is present. Also added tests which cause the four
-// methods that access information from the response (output, et c.) to throw an
-// InternalErr if they are called and is_response_present() would return false.
-//
-// Revision 1.1.2.7  2002/08/22 21:23:23  jimg
-// Fixes for the Win32 Build made at ESRI by Vlad Plenchoy and myslef.
-//
-// Revision 1.1.2.6  2002/08/08 06:54:57  jimg
-// Changes for thread-safety. In many cases I found ugly places at the
-// tops of files while looking for globals, et c., and I fixed them up
-// (hopefully making them easier to read, ...). Only the files RCReader.cc
-// and usage.cc actually use pthreads synchronization functions. In other
-// cases I removed static objects where they were used for supposed
-// improvements in efficiency which had never actually been verifiied (and
-// which looked dubious).
-//
-// Revision 1.1.2.5  2002/08/06 22:09:49  jimg
-// Removed old code about cache control.
-// Fixed set_credentials() so that it is MT-safe.
-//
-// Revision 1.1.2.4  2002/07/06 20:57:08  jimg
-// *** empty log message ***
-//
-// Revision 1.1.2.3  2002/07/06 20:08:08  jimg
-// Added support for proxies. Fixed the deflate stuff so that it matches the new
-// `sense' of the _dods_deflate field. Compression still does not work since
-// libcurl doesn't handle it yet.
-//
-// Revision 1.1.2.2  2002/06/20 03:18:48  jimg
-// Fixes and modifications to the Connect and HTTPConnect classes. Neither
-// of these two classes is complete, but they should compile and their
-// basic functions should work.
-//
-// Revision 1.1.2.1  2002/06/18 21:57:24  jimg
-// Created. This is a DODS interface to a HTTP library. This version uses
-// libwww. A lot of the methods here should be removed...
-//
