@@ -40,7 +40,13 @@ using namespace std;
     associated resources, this is overkill. However, some streams may require
     complex operations to free their resources once the client is done with
     the stream. Those classes should return a subclass of Response
-    which has those operations built into the destructor. */
+    which has those operations built into the destructor. 
+    
+    @todo If the code that parses the MIME headers was moved from Connect and
+    HTTPConnect to this class and its children, it would be easier to build
+    a FileConnect class (or maybe the specifics of the connection type could
+    be held in the Response object and HTTPConnect and the to be written 
+    FileConnect would not be needed). */
 class Response {
 private:
     /// The data stream
@@ -49,6 +55,8 @@ private:
     ObjectType d_type;
     /// Server version
     string d_version;
+    /// The DAP server's protocol
+    string d_protocol;
     /// The HTTP response code
     int d_status;
 
@@ -69,14 +77,13 @@ public:
 	HTTPResponse and HTTPConnect) may fill these fields in with other
 	values. */
     Response(FILE *s) : d_stream(s), d_type(unknown_type), 
-			d_version("dods/0.0"), d_status(0) { }
+			d_version("dods/0.0"), d_protocol("2.0"), 
+                        d_status(0) { }
 
     /** Close the stream. */
     virtual ~Response() { 
-	DBG(cerr << "Closing stream... ");
         if (d_stream)
 	    fclose(d_stream); 
-	DBGN(cerr << endl);
     }
 
     /** @name Accessors */
@@ -85,6 +92,7 @@ public:
     virtual FILE *get_stream() const { return d_stream; }
     virtual ObjectType get_type() const { return d_type; }
     virtual string get_version() const { return d_version; }
+    virtual string get_protocol() const { return d_protocol; }
     //@}
 
     /** @name Mutators */
@@ -93,43 +101,8 @@ public:
     virtual void set_stream(FILE *s) { d_stream = s; }
     virtual void set_type(ObjectType o) { d_type = o; }
     virtual void set_version(const string &v) { d_version = v; }
+    virtual void set_protocol(const string &p) { d_protocol = p; }
     //@}
 };
 
-// $Log: Response.h,v $
-// Revision 1.4  2005/01/28 17:25:12  jimg
-// Resolved conflicts from merge with release-3-4-9
-//
-// Revision 1.1.2.3  2004/08/24 20:03:15  jimg
-// Changed the way HTTPResponse deletes the temporary files created to hold
-// HTTP responses. Before this was done without using HTTPConnect's
-// close_temp() function. Instead, ~HTTPResponse() called unlink() on the
-// filename and then ~Response() called fclose on the FILE *. I think this
-// breaks on win32. THe simplest solution was to make ~HTTPResponse() use
-// the close_temp() function. I also had to edit the ~Response() method to
-// check that d_stream was not null before calling fclose() there.
-//
-// Revision 1.3  2004/02/19 19:42:52  jimg
-// Merged with release-3-4-2FCS and resolved conflicts.
-//
-// Revision 1.1.2.2  2004/02/11 22:26:46  jimg
-// Changed all calls to delete so that whenever we use 'delete x' or
-// 'delete[] x' the code also sets 'x' to null. This ensures that if a
-// pointer is deleted more than once (e.g., when an exception is thrown,
-// the method that throws may clean up and then the catching method may
-// also clean up) the second, ..., call(s) to delete gets a null pointer
-// instead of one that points to already deleted memory.
-//
-// Revision 1.2  2003/12/08 18:02:29  edavis
-// Merge release-3-4 into trunk
-//
-// Revision 1.1.2.1  2003/05/06 06:44:15  jimg
-// Modified HTTPConnect so that the response headers are no longer a class
-// member. This cleans up the class interface and paves the way for using
-// the multi interface of libcurl. That'll have to wait for another day...
-//
-// Revision 1.1  2003/03/04 05:57:40  jimg
-// Added.
-//
-
 #endif // response_h
