@@ -32,7 +32,7 @@
 #include "config.h"
 
 static char rcsid[] not_used =
-    { "$Id: SignalHandler.cc 11932 2005-08-11 22:26:27Z jimg $" };
+    { "$Id: SignalHandler.cc 13269 2006-02-24 18:54:20Z jimg $" };
 
 #include <signal.h>
 
@@ -96,14 +96,16 @@ SignalHandler::dispatcher(int signum)
 	return;
     else if (old_handler == SIG_DFL) {
 	switch (signum) {
+#ifndef WIN32
 	  case SIGHUP:
-	  case SIGINT:
 	  case SIGKILL:
+	  case SIGUSR1:
+	  case SIGUSR2:
 	  case SIGPIPE:
 	  case SIGALRM:
-	  case SIGTERM:
-	  case SIGUSR1:
-	  case SIGUSR2: _exit(EXIT_FAILURE);
+#endif
+	  case SIGINT:
+	  case SIGTERM: _exit(EXIT_FAILURE);
 
 	    // register_handler() should never allow any fiddling with
 	    // signals other than those listed above.
@@ -141,14 +143,16 @@ SignalHandler::register_handler(int signum, EventHandler *eh, bool override)
 {
     // Check first for improper use.
     switch (signum) {
+#ifndef WIN32
       case SIGHUP:
-      case SIGINT:
       case SIGKILL:
+      case SIGUSR1:
+      case SIGUSR2:
       case SIGPIPE:
       case SIGALRM:
-      case SIGTERM:
-      case SIGUSR1:
-      case SIGUSR2: break;
+#endif
+      case SIGINT:
+      case SIGTERM: break;
 
       default: throw InternalErr(__FILE__, __LINE__,
 		  string("Call to register_handler with unsupported signal (")
@@ -162,6 +166,7 @@ SignalHandler::register_handler(int signum, EventHandler *eh, bool override)
  
     // Register the dispatcher to handle this signal. See Stevens, Advanced
     // Programming in the UNIX Environment, p.298.
+#ifndef WIN32
     struct sigaction sa;
     sa.sa_handler = dispatcher;
     sigemptyset(&sa.sa_mask);
@@ -194,6 +199,7 @@ SignalHandler::register_handler(int signum, EventHandler *eh, bool override)
 	SignalHandler::d_old_handlers[signum] = SIG_IGN;
     else if (osa.sa_handler != dispatcher)
 	SignalHandler::d_old_handlers[signum] = osa.sa_handler;
+#endif
 
     return old_eh;
 }
@@ -210,76 +216,3 @@ SignalHandler::remove_handler(int signum)
 
     return old_eh;
 }
-
-// $Log: SignalHandler.cc,v $
-// Revision 1.6  2005/04/21 17:48:59  jimg
-// Removed PTHREADS compile-time switch. Also, checkpoint for the build
-// work.
-//
-// Revision 1.5  2004/07/07 21:08:48  jimg
-// Merged with release-3-4-8FCS
-//
-// Revision 1.4  2004/06/28 16:57:53  pwest
-// unix compiler issues
-//
-// Revision 1.1.2.12  2004/04/02 16:46:36  dan
-// Fixed aproblem with the Alpha build. Code didn't compile when HAVE_PTHREAD
-// was not defined.
-//
-// Revision 1.1.2.11  2004/03/11 18:21:59  jimg
-// Removed unneeded extra pthread_once_t mutex (was used for
-// re-initialization).
-//
-// Revision 1.1.2.10  2004/03/11 18:11:36  jimg
-// Ripped out the code in delete_instance that (tries to) reset(s) the
-// pthread_once_t mutex. We cannot do this in a portable way and it's needed
-// only for the unit tests, which I claim to have fixed so they don't require
-// it anymore.
-//
-// Revision 1.1.2.9  2004/03/07 23:17:44  rmorris
-// Make static initialization of PTHREAD_ONCE_INIT compatible cross platform.
-//
-// Revision 1.1.2.8  2004/02/27 17:25:12  edavis
-//  adding { } for PTHREAD_ONCE_INIT parm
-//
-// Revision 1.1.2.7  2004/02/26 22:44:50  edavis
-// remove the platform dependent parm PTHREAD_ONCE_INIT
-//
-// Revision 1.1.2.6  2004/02/22 23:35:03  rmorris
-// Solved some problems regarding the differences in the pthread
-// implementation across OSX, Win32 and non-OSX unixes. Either we are using
-// pthreads in a manner that was not intended by the pthread 'standard' (??)
-// or pthread implementations vary across platform or (finally) perhaps we
-// are encountering different implementations of pthreads as a result of its
-// development over time. Regardless our pthread code is starting to become
-// less portable. See how pthread_once_t varies across the above-mentioned
-// platforms. These changes get it to compile. I'm crossing my fingers that
-// it will run correctly everywhere.
-//
-// Revision 1.3  2004/02/19 19:42:52  jimg
-// Merged with release-3-4-2FCS and resolved conflicts.
-//
-// Revision 1.1.2.5  2004/02/11 17:12:01  jimg
-// Changed how this class creates its instance. It now does the same thing as
-// RCReader and is much more in line with HTTPCache.
-//
-// Revision 1.1.2.4  2004/02/10 20:48:13  jimg
-// Added support for running old handlers/actions once the newly registered
-// handlers are executed. Also limited the signals to those that POSIX.1 defines
-// as terminating the process by default. The code won't try to work with other
-// signals. It's possible to get it to do so, but fairly involved. See Steven's
-// "Advanced Programming ..." book for the lowdown on signals.
-//
-// Revision 1.2  2003/12/08 18:02:29  edavis
-// Merge release-3-4 into trunk
-//
-// Revision 1.1.2.3  2003/12/05 15:59:52  dan
-// Fixed compile error in #if HAVE_PTHREAD_H, else clause.  Was using
-// '_instance' when it should be 'd_instance'.
-//
-// Revision 1.1.2.2  2003/07/19 01:48:02  jimg
-// Fixed up some comments.
-//
-// Revision 1.1.2.1  2003/07/19 01:47:43  jimg
-// Added.
-//
