@@ -1,15 +1,16 @@
 
-// -*- mode: c++; c-basic-offset:4 -*-
+/* -*- mode: c; c-basic-offset:4 -*- */
 
-// Copyright (C) 1998 World Wide Web Consortium, (Massachusetts Institute
-// of Technology, Institut National de Recherche en Informatique et en
-// Automatique, Keio University). All Rights Reserved.
-// http://www.w3.org/Consortium/Legal/
-//    
+/* 
+   Copyright (C) 1998 World Wide Web Consortium, (Massachusetts Institute
+   of Technology, Institut National de Recherche en Informatique et en
+   Automatique, Keio University). All Rights Reserved.
+   http://www.w3.org/Consortium/Legal/
  
-// This file was derived from the libwww source code of 1998/08/20. The
-// copyright for the source of this derivative work can be found in the file
-// COPYRIGHT_W3C.
+   This file was derived from the libwww source code of 1998/08/20. The
+   copyright for the source of this derivative work can be found in the file
+   COPYRIGHT_W3C.
+*/
 
 /*
   Picked up from the w3c. 2/10/1998 jhrg
@@ -17,7 +18,7 @@
   Modified: Added the -s (silent) option to suppress diagnostic messages.
 */
 
-const char *rcsid={"$Id: deflate.c 11906 2005-08-08 19:51:43Z root $"};
+const char *rcsid={"$Id: deflate.c 13390 2006-03-08 16:47:54Z jimg $"};
 
 #include "stdlib.h"
 #include "string.h"
@@ -36,8 +37,8 @@ z_stream z;
 #define FALSE (0)
 #endif
 
-char *input_buffer 	= NULL;
-char *output_buffer 	= NULL;
+unsigned char *input_buffer 	= NULL;
+unsigned char *output_buffer 	= NULL;
 int  buffer_size 	= DEFAULT_BUFFER_SIZE;
 int  compression_rate	= DEFAULT_COMPRESSION;
 
@@ -101,8 +102,8 @@ int main (int argc, char ** argv)
 	}
     }
 
-    if ((input_buffer = (char *) calloc(1, buffer_size)) == NULL ||
-	(output_buffer = (char *) calloc(1, buffer_size)) == NULL) {
+    if ((input_buffer = (unsigned char *) calloc(1, buffer_size)) == NULL ||
+	(output_buffer = (unsigned char *) calloc(1, buffer_size)) == NULL) {
 	fprintf(stderr, "Not enough memory\n");
 	exit(-1);
     }
