@@ -33,6 +33,8 @@
 #include "AISMerge.h"
 #include "debug.h"
 
+#include "testFile.cc"
+
 using namespace CppUnit;
 
 class AISMergeTest:public TestFixture {
@@ -83,13 +85,6 @@ public:
 	    CPPUNIT_ASSERT(stuff.find(fnoc1_ais_string) 
 			   != string::npos);
 
-#if 0
-	    rv = ais_merge->d_ais_db.get_resource(bears);
-	    res = ais_merge->get_ais_resource(rv[0].get_url());
-	    CPPUNIT_ASSERT(dump2string(res->get_stream()).find(bears_1_ais_string) 
-			   != string::npos);
-#endif
-
 	    rv = ais_merge->d_ais_db.get_resource(coads);
 	    res = ais_merge->get_ais_resource(rv[0].get_url());
 	    CPPUNIT_ASSERT(dump2string(res->get_stream()).find(coads_ais_string) 
@@ -113,45 +108,43 @@ public:
 	try {
 	    Connect *conn;
 	    DAS das;
-	    ostringstream oss;
-
+            string sof;
+            
 	    conn = new Connect(fnoc1); // test overwrite (default)
 	    conn->request_das(das);
 	    ais_merge->merge(fnoc1, das);
-	    das.print(oss);
-	    DBG(cerr << "Merged fnoc1 DAS: " << oss.str() << endl);
-	    CPPUNIT_ASSERT(oss.str().find(fnoc1_merge_ais) != string::npos);
+	    FILE2string(sof, of, das.print(of));
+	    DBG(cerr << "Merged fnoc1 DAS: " << sof << endl);
+	    CPPUNIT_ASSERT(sof.find(fnoc1_merge_ais) != string::npos);
 
 	    delete conn; conn = 0;
 	    das.erase();
-	    oss.str("");
 
 	    conn = new Connect(fnoc2); // test replace
 	    conn->request_das(das);
 	    ais_merge->merge(fnoc2, das);
-	    das.print(oss);
-	    CPPUNIT_ASSERT(oss.str().find(fnoc2_merge_ais) != string::npos);
+	    FILE2string(sof, of, das.print(of));
+	    CPPUNIT_ASSERT(sof.find(fnoc2_merge_ais) != string::npos);
 
 	    delete conn; conn = 0;
 	    das.erase();
-	    oss.str("");
 	    
 	    conn = new Connect(fnoc3); // test fallback
 	    conn->request_das(das); // with a non-empty das, nothing happens
 	    ais_merge->merge(fnoc3, das);
-	    das.print(oss);
-	    CPPUNIT_ASSERT(oss.str().find(fnoc3_das) != string::npos);
+	    FILE2string(sof, of, das.print(of));
+	    CPPUNIT_ASSERT(sof.find(fnoc3_das) != string::npos);
 
-	    oss.str(""); das.erase(); // empty das, should add attributes
+	    das.erase(); // empty das, should add attributes
 	    ais_merge->merge(fnoc3, das);
-	    das.print(oss);
-	    CPPUNIT_ASSERT(oss.str().find(fnoc3_merge_ais) != string::npos);
+	    FILE2string(sof, of, das.print(of));
+	    CPPUNIT_ASSERT(sof.find(fnoc3_merge_ais) != string::npos);
 
 	    conn = new Connect(three_fnoc); // test regexp
 	    conn->request_das(das); // with a non-empty das, nothing happens
 	    ais_merge->merge(three_fnoc, das);
-	    das.print(oss);
-	    CPPUNIT_ASSERT(oss.str().find(three_fnoc_merge_ais) 
+	    FILE2string(sof, of, das.print(of));
+	    CPPUNIT_ASSERT(sof.find(three_fnoc_merge_ais) 
 			   != string::npos);
 	}
 	catch (Error &e) {
@@ -359,41 +352,3 @@ main( int, char** )
 
     return wasSuccessful ? 0 : 1;
 }
-
-// $Log: AISMergeTest.cc,v $
-// Revision 1.6  2004/02/19 19:42:51  jimg
-// Merged with release-3-4-2FCS and resolved conflicts.
-//
-// Revision 1.4.2.2  2004/02/11 22:26:45  jimg
-// Changed all calls to delete so that whenever we use 'delete x' or
-// 'delete[] x' the code also sets 'x' to null. This ensures that if a
-// pointer is deleted more than once (e.g., when an exception is thrown,
-// the method that throws may clean up and then the catching method may
-// also clean up) the second, ..., call to delete gets a null pointer
-// instead of one that points to already deleted memory.
-//
-// Revision 1.5  2003/12/08 18:02:29  edavis
-// Merge release-3-4 into trunk
-//
-// Revision 1.4.2.1  2003/09/06 22:11:02  jimg
-// Modified so that localhost is used instead of remote hosts. This means
-// that the tests don't require Internet access but do require that the
-// local machine runs httpd and has it correctly configured.
-//
-// Revision 1.4  2003/04/23 21:33:53  jimg
-// Changes for the unit tests. This involved merging Rob's VC++ changes
-// and fixing a bug in escaping.cc (a call to string::insert invalidated
-// an iterator in a loop).
-//
-// Revision 1.3  2003/03/12 01:07:34  jimg
-// Added regular expressions to the AIS subsystem. In an AIS database (XML)
-// it is now possible to list a regular expression in place of an explicit
-// URL. The AIS will try to match this Regexp against candidate URLs and
-// return the ancillary resources for all those that succeed.
-//
-// Revision 1.2  2003/03/04 17:56:43  jimg
-// Now uses Response objects.
-//
-// Revision 1.1  2003/02/25 23:29:52  jimg
-// Added.
-//
