@@ -34,9 +34,22 @@
 
 #include "AttrTable.h"
 
+#include "testFile.cc"
+
 using namespace CppUnit;
 using namespace std;
 
+static string
+build_fqn(AttrTable *at, string fqn)
+{
+    // The strange behavior at the top level is because the top level of an
+    // AttrTable (i.e. the DAS) is anonymous. Another bad design... jhrg 2/8/06
+    if (!at || !at->get_parent() || at->get_name().empty())
+        return fqn;
+    else
+        return build_fqn(at->get_parent(), at->get_name() + string(".") + fqn);
+}
+
 class AttrTableTest:public TestFixture {
 private:
     AttrTable *at1;
@@ -95,8 +108,9 @@ public:
     }
 
     CPPUNIT_TEST_SUITE( AttrTableTest );
-
     CPPUNIT_TEST(find_container_test);
+    CPPUNIT_TEST(get_parent_test);
+    CPPUNIT_TEST(recurrsive_find_test);
     CPPUNIT_TEST(find_test);
     CPPUNIT_TEST(copy_ctor);
     CPPUNIT_TEST(assignment);
@@ -113,6 +127,27 @@ public:
     CPPUNIT_TEST_SUITE_END();
 
     // Tests for methods
+    void recurrsive_find_test() {
+        AttrTable::Attr_iter location;
+        AttrTable *a = at1->recurrsive_find("color", &location);
+        CPPUNIT_ASSERT(a && a == cont_caa && a->get_name(location) == "color");
+        
+        a = cont_caa->recurrsive_find("color", &location);
+        CPPUNIT_ASSERT(a && a == cont_caa && a->get_name(location) == "color");
+        
+        a = at1->recurrsive_find("ba", &location);
+        CPPUNIT_ASSERT(a && a == cont_b && a->get_name(location) == "ba");
+    }
+    
+    void get_parent_test() {
+        CPPUNIT_ASSERT(cont_caa->get_parent() == cont_ca);
+        CPPUNIT_ASSERT(cont_ca->get_parent() == cont_c);
+        CPPUNIT_ASSERT(cont_c->get_parent() == at1);
+        CPPUNIT_ASSERT(at1->get_parent() == 0);
+        CPPUNIT_ASSERT(build_fqn(cont_caa, "color") == "c.ca.caa.color");
+    }
+    
+    
     void find_container_test() {
 	AttrTable *tmp = at1->find_container("a");
 	CPPUNIT_ASSERT(tmp != 0);
@@ -211,11 +246,11 @@ public:
 	AttrTable *t = new AttrTable;
 	t->append_attr("long name", "String", "first");
 	t->append_attr("longer name", "String", "\"second test\"");
-	ostringstream oss;
-	t->print(oss, "");
+        string sof;
+        FILE2string(sof, of, t->print(of, ""));
 	string attrs = "String long%20name first;\n\
 String longer%20name \"second test\";";
-	CPPUNIT_ASSERT(oss.str().find(attrs) != string::npos);
+	CPPUNIT_ASSERT(sof.find(attrs) != string::npos);
 	delete t; t = 0;
     }
 
@@ -227,21 +262,21 @@ String longer%20name \"second test\";";
 	    cont->add_value_alias(top, "an alias", "long name");
 	}
 	catch (Error &e) {
-	    e.display_message();
+	    cerr << e.get_error_message() << endl;
 	    CPPUNIT_ASSERT("Caught Error exception!" && false);
 	}
         try {
-	    ostringstream oss;
-	    top->print(oss, "");
+            string sof;
+            FILE2string(sof, of, top->print(of, ""));
 	    Regex r("Data%20Field \\{\n\
 .*String long%20name first;\n\
 .*Alias an%20alias long%20name;\n\
-\\}\n");
-	    CPPUNIT_ASSERT(re_match(r, oss.str().c_str()));
+\\}\n\n");
+	    CPPUNIT_ASSERT(re_match(r, sof.c_str()));
 	    delete top; top = 0;
         }
         catch (Error &e) {
-            e.display_message();
+            cerr << e.get_error_message() << endl;
             CPPUNIT_ASSERT("Caught Error exception!" && false);
         }
     }
@@ -250,12 +285,6 @@ String longer%20name \"second test\";";
 	int n = at1->get_size();
 	CPPUNIT_ASSERT(n == 3);
 
-#if 0
-	for (AttrTable::Attr_iter j = at1->attr_begin(); 
-	     j != at1->attr_end(); ++j) 
-	    cerr << "Name: " << at1->get_name(j) << endl;
-#endif
-
 	AttrTable::Attr_iter i = at1->get_attr_iter(0);
 	CPPUNIT_ASSERT(at1->get_name(i) == "a");
 	i = at1->get_attr_iter(2);
