@@ -67,7 +67,7 @@ public:
 	// above URL. The values below much match the etag and last-modified
 	// time returned by the server. Run this test with DODS_DEBUG defined
 	// to see the values it's returning.
-	etag = "\"3f62c-157-139c2680\"";
+	etag = "\"928ec-157-139c2680\"";
 	lm = "Wed, 13 Jul 2005 19:32:26 GMT";
 
 	localhost_pw_url = "http://jimg:dods_test@test.opendap.org/basic/page.txt";
@@ -201,11 +201,17 @@ public:
 	    DBG(copy(h->begin(), h->end(), 
 		     ostream_iterator<string>(cerr, "\n")));
 
-	    // Should get five headers back.
+	    // Should get five or six headers back.
 	    Regex header("XDODS-Server: DAP/.*");
 	    CPPUNIT_ASSERT(re_match(header, (*h)[0].c_str()));
+            Regex protocol_header("XDAP: .*");
+            unsigned int num_headers;
+            if (re_match(protocol_header, (*h)[1].c_str()))
+                num_headers = 7;
+            else
+                num_headers = 5;
 	    CPPUNIT_ASSERT((*h)[4] == "Content-Description: dods_das");
-	    CPPUNIT_ASSERT(h->size() == 5);
+	    CPPUNIT_ASSERT(h->size() == num_headers);
 
 	    delete r; r = 0;
 	}
@@ -366,88 +372,3 @@ main( int, char** )
     return wasSuccessful ? 0 : 1;
 }
 
-// $Log: HTTPConnectTest.cc,v $
-// Revision 1.11  2004/07/07 21:08:47  jimg
-// Merged with release-3-4-8FCS
-//
-// Revision 1.8.2.7  2004/06/21 20:46:38  jimg
-// Added a test for proxy use, including proxy authentication with a username
-// and password. A proxy server running on localhost must be configured for the
-// test to run.
-//
-// Revision 1.10  2004/02/19 19:42:52  jimg
-// Merged with release-3-4-2FCS and resolved conflicts.
-//
-// Revision 1.8.2.6  2004/02/11 22:26:46  jimg
-// Changed all calls to delete so that whenever we use 'delete x' or
-// 'delete[] x' the code also sets 'x' to null. This ensures that if a
-// pointer is deleted more than once (e.g., when an exception is thrown,
-// the method that throws may clean up and then the catching method may
-// also clean up) the second, ..., call to delete gets a null pointer
-// instead of one that points to already deleted memory.
-//
-// Revision 1.9  2003/12/08 18:02:29  edavis
-// Merge release-3-4 into trunk
-//
-// Revision 1.8.2.5  2003/09/06 22:11:02  jimg
-// Modified so that localhost is used instead of remote hosts. This means
-// that the tests don't require Internet access but do require that the
-// local machine runs httpd and has it correctly configured.
-//
-// Revision 1.8.2.4  2003/05/06 06:44:15  jimg
-// Modified HTTPConnect so that the response headers are no longer a class
-// member. This cleans up the class interface and paves the way for using
-// the multi interface of libcurl. That'll have to wait for another day...
-//
-// Revision 1.8.2.3  2003/05/05 21:44:50  jimg
-// Added test for password in url 'feature.'
-//
-// Revision 1.8.2.2  2003/05/05 19:46:40  jimg
-// Added set_accept_deflate test.
-//
-// Revision 1.8  2003/04/23 21:33:53  jimg
-// Changes for the unit tests. This involved merging Rob's VC++ changes
-// and fixing a bug in escaping.cc (a call to string::insert invalidated
-// an iterator in a loop).
-//
-// Revision 1.7  2003/04/22 19:40:27  jimg
-// Merged with 3.3.1.
-//
-// Revision 1.6  2003/03/04 17:21:47  jimg
-// Now uses Response objects.
-//
-// Revision 1.5  2003/02/21 22:49:52  jimg
-// Added fetch_url() tests for "file:" URLs.
-//
-// Revision 1.4  2003/02/21 00:14:24  jimg
-// Repaired copyright.
-//
-// Revision 1.3.2.1  2003/02/21 00:10:07  jimg
-// Repaired copyright.
-//
-// Revision 1.3  2003/01/23 00:22:24  jimg
-// Updated the copyright notice; this implementation of the DAP is
-// copyrighted by OPeNDAP, Inc.
-//
-// Revision 1.2  2003/01/10 19:46:40  jimg
-// Merged with code tagged release-3-2-10 on the release-3-2 branch. In many
-// cases files were added on that branch (so they appear on the trunk for
-// the first time).
-//
-// Revision 1.1.2.5  2002/12/24 02:39:48  jimg
-// Added cache test back into code.
-//
-// Revision 1.1.2.4  2002/11/06 21:53:06  jimg
-// I changed the includes of Regex.h from <Regex.h> to "Regex.h". This means
-// make depend will include the header in the list of dependencies.
-//
-// Revision 1.1.2.3  2002/10/18 22:53:17  jimg
-// Massive cahnges. Now tests read_url and also includes tests for accesses that use the HTTPCache class (as well as tests that force *not* using the cache).
-//
-// Revision 1.1.2.2  2002/09/14 03:41:31  jimg
-// Added tests for get_response_headers and is_response_present.
-//
-// Revision 1.1.2.1  2002/07/25 13:24:44  jimg
-// Added.
-//
-
