@@ -29,7 +29,7 @@
                          
 #include "config.h"
 
-static char rcsid[] not_used = {"$Id: util_mit.cc 12105 2005-09-08 15:08:58Z jimg $"};
+static char rcsid[] not_used = {"$Id: util_mit.cc 13266 2006-02-23 23:33:47Z jimg $"};
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -130,7 +130,7 @@ parse_time(const char * str, bool expand)
 
     if (!str) return 0;
 
-    if ((s = strchr(str, ','))) {	 /* Thursday, 10-Jun-93 01:29:59 GMT */
+    if ((s = (char *)strchr(str, ','))) {	 /* Thursday, 10-Jun-93 01:29:59 GMT */
 	s++;				/* or: Thu, 10 Jan 1993 01:29:59 GMT */
 	while (*s && *s==' ') s++;
 	if (strchr(s,'-')) {				     /* First format */
@@ -143,10 +143,13 @@ parse_time(const char * str, bool expand)
 	    }
 	    tm.tm_mday = strtol(s, &s, 10);
 	    tm.tm_mon = make_month(s, &s);
-	    tm.tm_year = strtol(++s, &s, 10);
+            ++s;
+	    tm.tm_year = strtol(s, &s, 10);
 	    tm.tm_hour = strtol(s, &s, 10);
-	    tm.tm_min = strtol(++s, &s, 10);
-	    tm.tm_sec = strtol(++s, &s, 10);
+            ++s;
+	    tm.tm_min = strtol(s, &s, 10);
+            ++s;
+	    tm.tm_sec = strtol(s, &s, 10);
 
 	} else {					    /* Second format */
 	    DBG(cerr <<"Format...... Wkd, 00 Mon 0000 00:00:00 GMT" << endl);
@@ -159,8 +162,10 @@ parse_time(const char * str, bool expand)
 	    tm.tm_mon = make_month(s, &s);
 	    tm.tm_year = strtol(s, &s, 10) - 1900;
 	    tm.tm_hour = strtol(s, &s, 10);
-	    tm.tm_min = strtol(++s, &s, 10);
-	    tm.tm_sec = strtol(++s, &s, 10);
+            ++s;
+	    tm.tm_min = strtol(s, &s, 10);
+            ++s;
+	    tm.tm_sec = strtol(s, &s, 10);
 	}
     } 
     else if (isdigit((int) *str)) {
@@ -175,11 +180,16 @@ parse_time(const char * str, bool expand)
 		return 0;
 	    }
 	    tm.tm_year = strtol(s, &s, 10) - 1900;
-	    tm.tm_mon  = strtol(++s, &s, 10);
-	    tm.tm_mday = strtol(++s, &s, 10);
-	    tm.tm_hour = strtol(++s, &s, 10);
-	    tm.tm_min  = strtol(++s, &s, 10);
-	    tm.tm_sec  = strtol(++s, &s, 10);
+            ++s;
+	    tm.tm_mon  = strtol(s, &s, 10);
+            ++s;
+	    tm.tm_mday = strtol(s, &s, 10);
+            ++s;
+	    tm.tm_hour = strtol(s, &s, 10);
+            ++s;
+	    tm.tm_min  = strtol(s, &s, 10);
+            ++s;
+	    tm.tm_sec  = strtol(s, &s, 10);
 
 	} else {					    /* delta seconds */
 	    t = expand ? time(NULL) + atol(str) : atol(str);
@@ -200,8 +210,10 @@ parse_time(const char * str, bool expand)
 	tm.tm_mon = make_month(s, &s);
 	tm.tm_mday = strtol(s, &s, 10);
 	tm.tm_hour = strtol(s, &s, 10);
-	tm.tm_min = strtol(++s, &s, 10);
-	tm.tm_sec = strtol(++s, &s, 10);
+        ++s;
+	tm.tm_min = strtol(s, &s, 10);
+        ++s;
+	tm.tm_sec = strtol(s, &s, 10);
 	tm.tm_year = strtol(s, &s, 10) - 1900;
     }
     if (tm.tm_sec  < 0  ||  tm.tm_sec  > 59  ||
